FirstScreen enum

The first screen to be shown in the sign-in experience.

Note it's not a part of the OIDC standard, but a Logto-specific extension.

Inheritance
Available extensions

Values

signIn → const FirstScreen
register → const FirstScreen
resetPassword → const FirstScreen
identifierSignIn → const FirstScreen
identifierRegister → const FirstScreen
singleSignOn → const FirstScreen

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on FirstScreen, provided by the FirstScreenExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FirstScreen>
A constant List of the values in this enum, in order of their declaration.