LogtoLinksClient class

Constructors

LogtoLinksClient({required LogtoConfig config, LogtoStorageStrategy? storageProvider, Client? httpClient, BrowserLaunchMode? launchMode})

Properties

config LogtoConfig
final
hashCode int
The hash code for this object.
no setterinherited
idToken Future<String?>
no setter
idTokenClaims Future<OpenIdClaims?>
no setter
isAuthenticated Future<bool>
no setter
loading bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAccessToken({String? resource, String? organizationId}) Future<void>
getAccessToken({String? resource, String? organizationId}) Future<AccessToken?>
getOrganizationToken(String organizationId) Future<AccessToken?>
getUserInfo() Future<LogtoUserInfoResponse>
handleSignInCallback(String callbackUri, String redirectUri) Future
launchBrowser(String url, {BrowserLaunchMode? launchMode}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signIn(String redirectUri, {String? loginHint, String? directSignIn, FirstScreen? firstScreen, List<IdentifierType>? identifiers, Map<String, String>? extraParams, int maxAge = 10 * 6000, BrowserLaunchMode? launchMode}) Future<void>
signOut({String? redirectUri, BrowserLaunchMode? launchMode}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited