LogtoUserScope enum
Scopes for ID Token and Userinfo Endpoint.
- Inheritance
- Available extensions
Values
- profile → const LogtoUserScope
-
Scope for basic user profile.
'name', 'picture', 'username', - email → const LogtoUserScope
-
Scope for user email.
- phone → const LogtoUserScope
-
Scope for user phone.
- customData → const LogtoUserScope
-
Scope for user;s custom data.
- identities → const LogtoUserScope
-
Scope for user's social identity details
- roles → const LogtoUserScope
-
Scope for user's roles
- organizations → const LogtoUserScope
-
Scope for user's organization IDs and perform organization token grant per RFC 0001.
- organizationRoles → const LogtoUserScope
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Available on LogtoUserScope, provided by the LogtoUserScopeUserScopeExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LogtoUserScope> - A constant List of the values in this enum, in order of their declaration.