LogtoReservedResource enum
Resources that reserved by Logto, which cannot be defined by users.
- Inheritance
- Available extensions
Values
- organization → const LogtoReservedResource
-
The resource for organization template per RFC 0001. @see {@link https://github.com/logto-io/rfcs | RFC 0001} for more details.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Available on LogtoReservedResource, provided by the LogtoReservedResourceExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LogtoReservedResource> - A constant List of the values in this enum, in order of their declaration.